# Powerpax: Utilities for JAX

[![Powerpax on PyPI](https://img.shields.io/pypi/v/powerpax)][pypi]
[![Powerpax on conda-forge](https://img.shields.io/conda/vn/conda-forge/powerpax.svg)][condaforge]
[![Documentation](https://readthedocs.org/projects/powerpax/badge/?version=latest)][docs]
[![Tests](https://github.com/karlotness/powerpax/actions/workflows/test.yml/badge.svg)][tests]

A collection of utility functions for JAX.

- **Documentation** https://powerpax.readthedocs.io/en/latest/
- **Source Code:** https://github.com/karlotness/powerpax
- **Bug Reports:** https://github.com/karlotness/powerpax/issues

## Installation
Install from [PyPI][pypi] using pip:
```console
$ python -m pip install powerpax
```
or from [conda-forge][condaforge]:
``` console
$ conda install -c conda-forge powerpax
```

This should install required dependencies, but JAX itself may require
special attention, particularly for GPU support.
Follow the [JAX installation instructions](https://jax.readthedocs.io/en/latest/installation.html).

## License
This software is distributed under the MIT license. See LICENSE.txt
for the license text.

[pypi]: https://pypi.org/project/powerpax/
[condaforge]: https://anaconda.org/conda-forge/powerpax
[docs]: https://powerpax.readthedocs.io/en/latest/
[tests]: https://github.com/karlotness/powerpax/actions/workflows/test.yml
